Examples
========
This folder contains some use cases using the **functional programming**
paradigm, the **dataflow programming** paradigm, and **schedula**:

#. **length_converter**, unit length converter (imperial and metric).
#. **processing_chain**, a chain of the process (``read``, ``process``,
   ``write``, ``plot``).
#. **symmetric_cryptography**, a tool and a web API service to handle symmetric
   cryptography.
